@@ -15,11 +15,11 @@ Test::Dependencies - Ensure that the dependency listing is complete
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =cut
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ In your t/00-dependencies.t:
     use File::Find::Rule::Perl;
 
     use Test::More;
-    use Test::Dependencies '0.27' forward_compatible => 1;
+    use Test::Dependencies '0.28' forward_compatible => 1;
 
     my $meta = CPAN::Meta->load_file('META.yml');
     plan skip_all => 'No META.yml' if ! $meta;
@@ -309,14 +309,14 @@ sub ok_dependencies {
         my $first_in = Module::CoreList->first_release($mod, $required{$mod});
         if (my $v = Module::CoreList->removed_from($mod)) {
             $v = version->parse($v)->normal;
-            $tb->ok($required{$mod},
-                    "Removed-from-CORE (since $v) module '$mod' "
+            $tb->ok(exists $required{$mod},
+                    "Removed-from-CORE (in $v) module '$mod' "
                     . 'explicitly required');
         }
         elsif (my $v = Module::CoreList->deprecated_in($mod)) {
             $v = version->parse($v)->normal;
-            $tb->ok($required{$mod},
-                    "Deprecated-from-CORE (since $v) module '$mod' explicitly "
+            $tb->ok(exists $required{$mod},
+                    "Deprecated-from-CORE (in $v) module '$mod' explicitly "
                     . 'required to anticipate removal');
         }
         elsif (defined $first_in) {
